"use client";
import { IconButton, Modal } from "@mui/material";
import { Swiper, SwiperSlide } from "swiper/react";
import { Pagination, Navigation, Zoom } from "swiper/modules";
import { GalleryContext } from "@/providers/ProductGalleryProvider";
import { useContext } from "react";

import "swiper/css/navigation";
import "swiper/swiper-bundle.css";
import "swiper/css/zoom";
import "swiper/css/pagination";

import Image from "next/image";
import { Close } from "@mui/icons-material";

const ProductPreviewGalleryModal = () => {
  const { images, toggleGallery, handleGalleryToggeler } =
    useContext(GalleryContext);
  return (
    <Modal open={toggleGallery} onClose={handleGalleryToggeler}>
      <div className="w-full h-full flex flex-col gap-3 ">
        <div className="w-full  p-3 ">
          <IconButton
            sx={{ backgroundColor: "#ffffff" }}
            onClick={handleGalleryToggeler}
          >
            <Close />
          </IconButton>
        </div>
        <div className="w-full flex flex-1 p-5">
          <Swiper
            style={{
              "--swiper-navigation-color": "#71C9CD",
              "--swiper-pagination-color": "#71C9CD",
              height: "100%",
              width: "100%",
            }}
            zoom={true}
            navigation={true}
            pagination={{
              clickable: true,
            }}
            spaceBetween={10}
            slidesPerView={1}
            modules={[Zoom, Navigation, Pagination]}
          >
            {images.map((item, index) => (
              <SwiperSlide
                key={index.toString()}
                className="h-full max-h-full box-border "
              >
                <div className="swiper-zoom-container ">
                  <Image
                    src={item.image}
                    width={"0"}
                    height={"0"}
                    sizes="100vw"
                    className="w-auto h-[70vh]  object-contain rounded-lg"
                    alt={item.alt}
                    title={item.title}
                  />
                </div>
              </SwiperSlide>
            ))}
          </Swiper>
        </div>
      </div>
    </Modal>
  );
};

export default ProductPreviewGalleryModal;
